<?php
/**
 * Contains Util Classes.
 *
 * General Utilities
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>, http://wp.leau.co
 * @copyright GPL 2
 */

namespace leau\co\wp_favicons;


if (!class_exists("EdlUtils"))
{

	/**
	 * Class: EdlUtils
	 *
	 * @since 0.1
	 * @author Edward de Leau <e@leau.net>
	 * @copyright GPL 2
	 * @static class containing utility functions
	 */
	class EdlUtils
	{
		CONST LOGLEVEL = 3;

		// singleton instance
		private static $instance;

		// private constructor function
		// to prevent external instantiation
		private function __construct()
		{

		}
		private function __clone()
		{
		}

		// getInstance method
		public static function getInstance()
		{
			if(!self::$instance)
			{
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Writes a file
		 * Writes a file to a directory
		 * @param $dir
		 * @param $file
		 * @param $content
		 */
		public static function WriteFile($dir,$file,$content)
		{
			if (!is_dir($dir)) {
				mkdir($dir, 0755, true);
			}
			$fh = fopen($file, 'w') or die("can't open file");
			fwrite($fh, $content);
			echo "<!-- " . $file ." written -->";
			fclose($fh);
		}

		// from http://php.net/manual/en/function.serialize.php
		/**
		 * converts an array to string
		 * @param $array
		 * @param $level
		 */
		function array2str($array,$level=1)
		{
			$str = array();
			foreach($array as $key=>$value)
			{
				$nkey = base64_encode($key);
				$nvalue = is_array($value)?'$'.base64_encode(array2str($value)) : (string)base64_encode($value);
				$str[] = $nkey.'&'.$nvalue;
				//	printf("Encoded %s,%s to %s,%s\n",$key,$value,$nkey,$nvalue);
			}
			return implode('|',$str);
		}

		/**
		 * converts a string to an array
		 * @param $str
		 */
		function str2array($str)
		{
			$rest = array();
			if(strpos($str,'|')>0)
			{
				$array = explode('|',$str);
			}
			else
			{
				$array=array($str);
			}
			foreach($array as $token)
			{
				list($key,$value) = explode('&',$token);
				$nkey=base64_decode($key);
				$nvalue = (substr($value,0,1) != '$' ? base64_decode($value) : str2array(base64_decode(substr($value,1))) );
				$rest[$nkey] = $nvalue;
				//printf("Decoded %s,%s to %s,%s\n",$key,$value,$nkey,$nvalue);
			}
			return $rest;
		}

		/**
		 * Some admin fields we use currently
		 * Will add some more in later releases
		 * @param $field
		 * @param $fieldname
		 * @param $fieldvalue
		 * @uses checked as defined in \wp-includes\general-template.php
		 *
		 * @todo 0.5.0 refine e.g. esc and extend these helpers with more fields
		 */
		function AdminForm($field,$fieldname,$fieldvalue)
		{
			switch ($field['type']) {
				case 'radio_bool':
					echo '<input ';
					echo 'type="radio" ';
					echo 'name="' . $fieldname . '" ';
					echo 'id="' . $fieldname . '" ';
					echo ' value="1" ';
					checked( '1', $fieldvalue );
					echo ' /> yes <br />';

					echo '<input ';
					echo 'type="radio" ';
					echo 'name="' . $fieldname . '" ';
					echo 'id="' . $fieldname . '" ';
					echo ' value="0" ';
					checked( '0', $fieldvalue );
					echo " /> no";
					break;
				case 'text':
					echo '<input ';
					echo 'type="text" ';
					echo 'name="' . $fieldname . '" ';
					echo 'id="' . $fieldname . '" ';
					echo 'value="' . $fieldvalue . '" ';
					echo 'size="150" ';
					echo " />";
					break;
				case 'text_no_change':
					echo '<input ';
					echo 'type="text" ';
					echo 'name="' . $fieldname . '" ';
					echo 'id="' . $fieldname . '" ';
					echo 'value="' . $fieldvalue . '" ';
					echo 'size="150" disabled';
					echo " />";
					break;
				case 'textarea':
					echo '<textarea ';
					echo 'name="' . $fieldname . '" ';
					echo 'rows="5" ';
					echo 'cols="80" ';
					echo '>';
					echo $fieldvalue;
					echo '</textarea>';
					break;
			}

		}

		/**
		 * Outputs a message in the screen output
		 * Handy for debugging
		 * @param unknown_type $url
		 * @param unknown_type $msg
		 */
		function favicon_page_msg($url,$msg) {
			if (is_user_logged_in() && current_user_can('activate_plugins'))
			{
				echo "\n<!-- [WP-FAVICONS]:";
				echo $url;
				echo " " . $msg;
				echo " -->\n";
			}
		}

		/**
		 *
		 * Enter description here ...
		 * @param $favicon_array
		 * @param $url
		 */
		function favicon_filter_init( /*array*/ $favicon_array, /*string*/ $url)
		{
			/* always check that no icon has been found yet */
			$favicon_found = false;
			if ($favicon_array)
			{
				if (array_key_exists('data', $favicon_array) &&
						'' != $favicon_array['data'])
				{
					return false;
				}
			}

			// testing larger time-out
			if( !ini_get('safe_mode') ){
				//echo ini_get('max_execution_time');
				ini_set('max_execution_time',1000);
				set_time_limit(1000);
			}

			//add_filter( 'http_request_timeout', 5)
			//add_filter( 'http_request_redirection_count', 5)
			//add_filter( 'http_request_version', '1.0')
			//add_filter( 'http_headers_useragent', 'WordPress/' . $wp_version . '; ' . get_bloginfo( 'url' )  )

			/* otherwise get it */
			$response = wp_remote_get($url);
			if ( is_wp_error( $response ))
			{
				$error_string = $response->get_error_message();
				echo "<!-- [WP-FAVICONS]: " .  $error_string  . " -->";
				return false;
			}
			else
			{
				//
				// @todo 0.5.0 check for images and pages return
				// error codes in ico format for error pages
				// with option to strike the corresponding URI
				//
				// @todo 0.5.0 sometimes we get redirected to a html page
				// which HAS a favicon but then even in the page itself...
				// e.g. type newscred.com -> forwards to platform.newscred.com
				// --> /favicon.ico ---> forwards to newspaper.newscred.com
				// uhm...
				if ($response['response']['code'] != 200)
				{
					echo "<!-- ";
					print_r($response['headers']);
					print_r($response['response']);
					echo " -->";
					return false;
				}
				else
				{
					//echo "<!-- ";
					//print_r($response['headers']);
					//print_r($response['response']);
					//echo " -->";
					$data = $response['body'];
				}
			}

			if (!$data)
			{
				return false;
			}
			return $data;
		}
	}
}