<?php
/**
 * Deletes the Favicon Cache
 * @package WP-Favicons
 * @author Edward de Leau <e@leau.net>, http://edward.de.leau.net
 * @since 0.4.0
 */
namespace leau\co\wp_favicons;

if (!class_exists("cache_empty_cache"))
{
	/**
	 * Deletes the Favicon Cache
	 * This plugin offers functionality to delete the favicon cache
 	 * @author Edward de Leau <e@leau.net>, http://edward.de.leau.net
 	 * @since 0.4.0 *
	 */
	class cache_empty_cache extends Plugin
	{
		/**
		* Delete a file, or a folder and its contents
		*
		* @author Aidan Lister <aidan@php.net>
		* @version 1.0.2
		* @param string $dirname Directory to delete
		* @return bool Returns TRUE on success, FALSE on failure
		*/
		function rmdirr($dirname)
		{
			// Sanity check
			if (!file_exists($dirname)) {
				return false;
			}

			// Simple delete for a file
			if (is_file($dirname)) {
				return unlink($dirname);
			}

			// Loop through the folder
			$dir = dir($dirname);
			while (false !== $entry = $dir->read()) {
				// Skip pointers
				if ($entry == '.' || $entry == '..') {
					continue;
				}

				// Recurse
				$this->rmdirr("$dirname/$entry");
			}

			// Clean up
			$dir->close();
			return rmdir($dirname);
		}

		/**
    	 * Executes admin functions
    	 *
    	 */
     	function ExecuteAdminAction()
        { 	$options_array = Config::GetOptionsAsArray();
        	if (Config::GetOptionsArrayValue(Config::GetPluginSlug() . 'empty_cache') == 1)
        	{
            	if (Config::GetOptionsArrayValue('wp_favicons_upload_dir'))
            	{
        			$this->rmdirr(Config::GetOptionsArrayValue('wp_favicons_upload_dir'));

            	}
				// delete the db cache
				Database::EmptyIconCache();

            	// now set the option back to 1 again
				$options_array[Config::GetPluginSlug() . 'empty_cache'] = 0;
				Config::UpdateOptions($options_array);
				Config::AddOptions(array('cache_emptied_date' => current_time("mysql")));
				Config::SetModulePlugin($this->_module,$this->_plugin,'header',
				'Empty the current cache. Last time Emptied on: ' .
				Config::GetOptionsArrayValue('cache_emptied_date'));

        	}
        }
	}
}

