<?php
/**
 * Contains Classes for managing the an Eternal Cache based on a  reversed url structure.
 *
 * @package WP-Favicons
 * @since 0.030
 * @author Edward de Leau <e@leau.net>
 * @copyright Edward de Leau, http://edward.de.leau.net
 */
namespace leau\co\wp_favicons;

if (!class_exists("EdlLinkFaviconCache")) {

	/**
 	 * Class: EdlLinkFaviconCache
     * Caching of favicons based on a domain e.g. \com\delicious\www\[cache location]
     * so always a url is passed to determine the cache location on. Remnants of
     * a more larger generic class
     * @package WP-Favicons
   	 * @since 0.4.0
 	 * @author Edward de Leau <e@leau.net>, http://edward.de.leau.net
 	 * @copyright GPL 2
     */
	class EdlLinkFaviconCache {

		public $url;
		public $physical_location;
		public $physical_location_and_file;
		public $relative_location;
		public $file_name;
		public $file_content;

		/*
		 * constructor
		 */
		public function __construct($url, $fileName)
		{
			/* calculate the relative reverse domain dir */
			$this->SetUrl($url);

			if ($fileName)
			{
				$this->SetFileName($fileName);
			}

			$this->physical_location_and_file = $this->physical_location .
				$this->file_name;
		}

		/**
		 * URL based dir calculation
		 * Based on the url given the physical / relatieve domain based
		 * directories are calculated
		 * @param string $url the url passed
		 */
		function SetUrl($url) {
			$write_loc = '';
			if ($url)
			{
				$url_array = Array();
				$this->url = $url;
				$url_host = parse_url($url, PHP_URL_HOST);

				// and now we also know the cache location
				// 1. first make the path for the root domain:
				if (Database::valid_ip($url_host))
				{
					$write_loc .= '/' . $url_host;
				}
				else
				{
					$segments = array_reverse(explode('.',$url_host));
					foreach($segments as $segment) {
						$write_loc .= '/' . $segment;
					}
				}
				// 3. add ports
				$url_port = parse_url($url, PHP_URL_PORT);
				if ($url_port)
				{
					$write_loc .= '/' . $url_port;
				}

				// 3. then check for special paths that we want to use for specific
				//    path based root domains we specify e.g. apps.facebook.com
				// @todo 0.5.0 add this as  plugin to add more
				// see database file for thoughts on domain vs paths to
				// somehow make one unique location per favicon:
				// idea: store the md5 sum of the data in the database
				// when one of the grandfathers carries the same md5 do not
				// copy it in.
				// and the other way around: if one of the nephews in the tree
				// already has a favicon, move it up.
				// another idea: run optimilizations of finding 'owner nodes'
				//

				if ($url_host === 'apps.facebook.com') {
					$write_loc .= $url_array['path'];
				}
			}
			$write_loc = substr($write_loc, 1);

			$this->relative_location = Config::GetOptionsArrayValue(Config::GetPluginSlug() .
						'upload_url_cache') . $write_loc . '/';
			$this->physical_location = Config::GetOptionsArrayValue(Config::GetPluginSlug() .
						'upload_dir_cache') . $write_loc . '/';
			return true;
		}

		/*
		 * the filename of the file we want to cache
		 */
		function SetFileName($filename)
		{
			$this->file_name = $filename;
			$this->physical_location_and_file = $this->physical_location . '/' . $this->file_name;
			return true;
		}

		/*
		 *
		 */
		function SetContent($filecontent)
		{
			$this->file_content = $filecontent;
			return true;
		}

		/*
		 *
		 */
		function GetRelativeLocation() {
			return $this->relative_location;
		}

		/*
		 *
		 */
		function GetPhysicalPathAndFile() {
			return $this->physical_location_and_file;
		}

		/*
		 * check if the file exists we want to cache
		 * if it does not write it
		 * always return true unless error
		 */
		function FileExistInCache()
		{
			if (file_exists($this->physical_location_and_file))
			{
				return true;
			}
			else
			{
				return false;
			}
		}

		/*
		 * write the file to cache
		 */
		function WriteFileToCache()
		{
			EdlUtils::WriteFile($this->physical_location,
				$this->physical_location_and_file,
				$this->file_content);
		}

		/*
		 * read cache
		 */
		function ReadFileFromCache()
		{
			$data = @file_get_contents($this->physical_location_and_file);
			return $data;
		}

		/**
		 * direct save to cache
		 * @since 0.4.0
		 * @param $data
		 */
		function Savedata($data)
		{
			if (!$this->FileExistInCache())
			{
				$this->SetContent($data);
				$this->WriteFileToCache();
			}
		}

	}
}