<?php
/**
 * Filter to get an identicon as a default icon for a url
 *
 * This file get an identicon from the Gravatar service as default url
 *
 * Note: feel free to add your own filters!
 *
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>
 * @copyright Edward de Leau, http://edward.de.leau.net
 */

namespace leau\co\wp_favicons;

/**
 * Gets an Identicon
 * @param $favicon_array
 * @param $url
 */
if (!class_exists("default_identicon"))
{
	class default_identicon  extends Plugin
	{
		/**
		 * (non-PHPdoc)
		 * @see plugins/EdlLinkFaviconPlugin::AddFilter()
		 */
		function AddFilter()
		{
			add_filter('wp_favicons_default', array($this,'ExecuteFilter'), 99, 2);
		}

		function ExecuteFilter( /*array*/ $favicon_array, /**/ $url)
		{
			/* BEGIN CHECK: All filters MUST start with this check */
			$url2 = 'http://0.gravatar.com/avatar/'.md5($url).'?default=identicon&s=32';
			if (!$data = EdlUtils::favicon_filter_init($favicon_array, $url2)) return $favicon_array;
			/* END CHECK */

			$id = Database::LogFaviconFound(array(
				 	'uri' => $url,
					'type' => 'png',
					'filetypesure' => true,
					'data' => $data,
					'default' => true,
					'comment' => $url,
					'source'=> 'IDENTICON'));

			$favicon_array['id'] = $id;
			$favicon_array['type'] = 'pngsure';
			$favicon_array['data'] = $data;
			EdlUtils::favicon_page_msg($url,' [DEFAULT_IDENTICON] FOUND !');
			return 	$favicon_array;
		}
	}
}

