<?php
/**
 * Filter to convert a favicon to PNG.
 *
 * This file contains the wp_favicons_convert filter implementation
 * to convert a favicon to PNG.
 *
 * Note: feel free to add your own filters!
 *
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>
 * @copyright Edward de Leau, http://edward.de.leau.net
 */

namespace leau\co\wp_favicons;

/**
 *
 * Enter description here ...
 * @package WP-Favicons
 * @param $favicon_array
 */
if (!class_exists("filters_convert_to_png"))
{
	class filters_convert_to_png extends Plugin
	{
		/**
		 * Gets the filetype of an image
		 * @param $data
		 * @param $filetype
		 */
		function GetFileType($data, $filetype)
		{
			/* we need a physical file to determine file type */
			$admin_options = get_option('wp_favicons_options');
			$tempdir = $admin_options['wp_favicons_upload_dir_cache'];
			$tempfile = $tempdir . '/' . 'temp.' . $filetype;
			EdlUtils::favicon_page_msg('','[PNG_CONVERSION] '. $tempdir . 'temp.' . $filetype . ' found');
			EdlUtils::WriteFile($tempdir, $tempfile,  $data);
			EdlUtils::favicon_page_msg('','[PNG_CONVERSION] '. $tempdir . 'temp.' . $filetype . ' written');

			/* check type via exif_imagetype */
			$filetype='';
			if ( ! function_exists( 'exif_imagetype' ) )
			{
				if ( ( list($width, $height, $type, $attr) = getimagesize( $tempfile ) ) !== false )
				{
					$type_to_check = $type;
				}
				else
				{
					EdlUtils::favicon_page_msg('','[PNG_CONVERSION] no PHP EXIF and no PHP IMAGETYPE');
					$type_to_check = '';
				}
			}
			else
			{
				$type_to_check = exif_imagetype($tempfile);
			}

			switch($type_to_check)
			{
				case IMAGETYPE_ICO:
					$filetype = 'ico';
					break;
				case IMAGETYPE_GIF:
					$filetype = 'gif';
					break;
				case IMAGETYPE_JPEG:
					$filetype = 'jpg';
					break;
				case IMAGETYPE_PNG:
					$filetype = 'png';
					break;
				case IMAGETYPE_ICO:
					$filetype = 'png';
					break;
				case IMAGETYPE_BMP:
					$filetype = 'bmp';
					break;
				case IMAGETYPE_XBM:
					$filetype = 'xbm';
					break;
				case IMAGETYPE_WBMP:
					$filetype = 'wbmp';
					break;
				default:
					EdlUtils::favicon_page_msg('','[PNG_CONVERSION] '. $type_to_check . ' found');
					$filetype = '';
					break;
			}
			return $filetype;
		}

		/**
		 * Converts an ico to png
		 * @param $data
		 */
		function ConvertIcoToImage($data)
		{
			// imagecreatefromstring did not work for ico
			// found class on http://www.tom-reitz.com/2009/02/09/ico-images-in-facebook-profile-boxes/
			$image='';
			$icon = new Ico();
			if(!($icon->LoadData($data)))
			{
				EdlUtils::favicon_page_msg('','[PNG_CONVERSION] could not load the ico...');
			}
			else
			{
				EdlUtils::favicon_page_msg('','[PNG_CONVERSION] loaded the ico...');
			}
			if(!($image=$icon->GetIcon(0)))
			{
				EdlUtils::favicon_page_msg('','[PNG_CONVERSION] could not get ico data from ico...');
			}
			else
			{
				EdlUtils::favicon_page_msg('','[PNG_CONVERSION] got image from ico...');
			}
			return $image;
		}

		/**
		 * Make an PNG from an image
		 * lots of nice info on http://php.net/manual/en/function.imagepng.php
		 * Enter description here ...
		 * @param $image
		 */
		function GetConvertedPNGImage($image)
		{
			ob_start();
			imagealphablending($image, true); // setting alpha blending on
			imagesavealpha($image, true); // save alphablending setting (important)
			imagepng($image, NULL, 0, NULL);
			$image_png = ob_get_contents();
			ob_end_clean();
			return $image_png;
		}

		/**
		 * Adds the png converter functionality
		 */
		function AddFilter()
		{
			add_filter('wp_favicons_convert', array($this,'ExecuteFilter'), 6, 2);
		}

		/**
		 * Executes the functionality of the png converter
		 * @param $favicon_array
		 */
		function ExecuteFilter( /*array*/ $favicon_array )
		{
			if ( ! function_exists('imagecreatefromstring') )
			echo '<!-- The GD image library is not installed. -->';

			if (!$favicon_array) {return $favicon_array;}

			/* if already a PNG for sure: nothing todo : just return */
			if ('pngsure' == $favicon_array['type'])
			{
				EdlUtils::favicon_page_msg('',
						'[PNG_CONVERSION] no need to convert we know for sure its a png...');
				return $favicon_array;
			}
			/* if ICO for sure: convert and return */
			elseif ('icosure' == $favicon_array['type'])
			{
				EdlUtils::favicon_page_msg('',
						'[PNG_CONVERSION] we need for sure that we need to convert the ico...');
				$image='';
				$image = $this->ConvertIcoToImage($favicon_array['data']);
				$image = $this->GetConvertedPNGImage($image);
				$favicon_array['data'] = $image;
				$favicon_array['type'] = 'pngsure';
				return $favicon_array;
			}
			else
			{
				/* determine the filetype */
				EdlUtils::favicon_page_msg('','[PNG_CONVERSION] the extension says its not a png...');
				$filetype2 = $this->GetFileType($favicon_array['data'], $favicon_array['type']);

				/* if ico: convert and return */
				if ('ico' == $filetype2)
				{
					$image='';
					$image = $this->ConvertIcoToImage($favicon_array['data']);
					$image = $this->GetConvertedPNGImage($image);
					$favicon_array['data'] = $image;
					$favicon_array['type'] = 'pngsure';
					Database::UpdateFaviconFoundWithFilter('PNG', $favicon_array['id'] ,' converted ICO to PNG', 'png');
					return $favicon_array;
				}
				/* if png: just return */
				elseif('png' == $filetype2)
				{
					EdlUtils::favicon_page_msg('','[PNG_CONVERSION] it is already a png...');
					$favicon_array['type'] = 'pngsure';
					Database::UpdateFaviconFoundWithFilter('PNG', $favicon_array['id'] ,' renamed to PNG', 'png');
					return $favicon_array;
				}
				/* for all other filetypes: convert */
				else
				{
					$image='';
					$image = @imagecreatefromstring($favicon_array['data']);
					if ( !is_resource( $image ) )
					{
						// @todo 0.5.0 this goes sometimes wrong and should be extended
						EdlUtils::favicon_page_msg('','[PNG_CONVERSION] : this is not an image! :' . $filetype2);
						$favicon_array='';
						return $favicon_array;
					}
					else
					{
						$image = $this->GetConvertedPNGImage($image);
						$favicon_array['data'] = $image;
						$favicon_array['type'] = 'pngsure';
						Database::UpdateFaviconFoundWithFilter('PNG', $favicon_array['id'] ,' converted to PNG', 'png');
						return $favicon_array;
					}
				}
			}
			EdlUtils::favicon_page_msg('','[PNG_CONVERSION] something went wrong!');
			return $favicon_array;
		}
	}
}