<?php
/**
 * Filter to get a favicon from Google's Favicon provider
 *
 * This file contains the wp_favicons_search filter implementation
 * to get a favicon.ico from Google S2 favicon service
 * {@link http://stackoverflow.com/questions/4584895/favicon-to-png-in-php/4718629#4718629}
 *
 * Note: feel free to add your own filters!
 *
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>, {@link http://wp.leau.co}
 * @copyright GPL 2
 */
namespace leau\co\wp_favicons;
if (!class_exists("sources_google_s2"))
{
	/**
 	 * Filter to get a favicon from Google's Favicon provider
 	 * @package WP-Favicons
     * @since 0.4.0
     * @author Edward de Leau <e@leau.net>, {@link http://wp.leau.co}
     * @copyright GPL 2
 	 */
	class sources_google_s2 extends Plugin
	{
		public $_data_url = '';

	 	/**
    	 * (non-PHPdoc)
    	 * @see plugins/EdlLinkFaviconPlugin::AddFilter()
    	 */
    	function AddFilter()
    	{
    		/* parent class arranges that this is not called when the bool is off */
    		add_filter(Config::GetPluginSlug() . 'search', array($this,'DoFilter'), 6, 2);
    	}

		/**
		 *
		 * Enter description here ...
		 * @param $favicon_array
		 * @param $url
		 */
		function DoFilter( /*array*/ $favicon_array, /*string*/ $url)
		{
			$data_url = $this->DataUrl($url);
			/* the following three lines should always be the executed */
			if (!$data = EdlUtils::favicon_filter_init($favicon_array, $data_url)) { return $favicon_array; }
			$favicon_array = $this->ExecuteFilter($favicon_array, $url, $data);
			return $favicon_array;
		}

    	/**
    	 * (non-PHPdoc)
    	 * @see plugins/search/inc/EdlLinkFaviconPluginSources::DataUrl()
    	 */
    	function DataUrl($url)
    	{
    		$this->_data_url = 'http://www.google.com/s2/favicons?domain=' .
				parse_url($url, PHP_URL_HOST);
			return $this->_data_url;
    	}

		/**
		 *
		 * Enter description here ...
		 * @param $favicon_array
		 * @param $url
		 */
		function ExecuteFilter(/*array*/ $favicon_array, /*string*/ $url, $data)
		{
			//if it is the default icon skip it maybe other providers can deliver a better image
			if (md5($data) == 'b8a0bf372c762e966cc99ede8682bc71')
			{
				EdlUtils::favicon_page_msg($url,' [GOOGLE] NOT FOUND');
				return $favicon_array;
			}
			else
			{
				/* google always returns png */
				$id = Database::LogFaviconFound(array(
				 	'uri' => $url,
					'type' => 'png',
					'filetypesure' => true,
					'data' => $data,
					'default' => false,
					'comment' => $url,
					'source'=> 'googles2'));
				$favicon_array['type'] = 'pngsure';
				$favicon_array['data'] = $data;
				$favicon_array['id'] = $id;
				EdlUtils::favicon_page_msg($url,' [GOOGLE] FOUND !');
				return $favicon_array;
			}
			return $favicon_array;
		}
	}
}