<?php
/**
 * Filter to Extract a favicon from the root of a domain
 *
 * This file contains the wp_favicons_search filter implementation
 * to get a favicon.ico from the root of a domain
 *
 * Note: feel free to add your own filters!
 *
 * @package WP-Favicons
 * @since 0.4.0
 * @author Edward de Leau <e@leau.net>
 * @copyright Edward de Leau, http://edward.de.leau.net
 */

namespace leau\co\wp_favicons;

/**
 *
 * Enter description here ...
 * @param unknown_type $favicon_array
 * @param unknown_type $url
 */
if (!class_exists("sources_root"))
{
	class sources_root extends Plugin
	{
		public $_data_url = '';

	 	/**
    	 * (non-PHPdoc)
    	 * @see plugins/EdlLinkFaviconPlugin::AddFilter()
    	 */
    	function AddFilter()
    	{
    		/* parent class arranges that this is not called when the bool is off */
    		add_filter(Config::GetPluginSlug() . 'search', array($this,'DoFilter'), 6, 2);
    	}

		/**
		 *
		 * Enter description here ...
		 * @param $favicon_array
		 * @param $url
		 */
		function DoFilter( /*array*/ $favicon_array, /*string*/ $url)
		{
			$data_url = $this->DataUrl($url);
			/* the following three lines should always be the executed */
			if (!$data = EdlUtils::favicon_filter_init($favicon_array, $data_url)) { return $favicon_array; }
			/* check that data is an icon not a redirected page */
			if (strpos(strtolower("-".$data),strtolower('<html'))) {

				if (strpos(strtolower("-".$data),strtolower('<body'))) {

					return $favicon_array;
				}
			}
			/* @todo 0.5.0 add more redirection support

			$favicon_array = $this->ExecuteFilter($favicon_array, $url, $data);
			return $favicon_array;
		}



    	/**
    	 * (non-PHPdoc)
    	 * @see plugins/search/inc/EdlLinkFaviconPluginSources::DataUrl()
    	 */
    	function DataUrl($url)
    	{
    		$this->_data_url = 'http://' . parse_url($url,PHP_URL_HOST) . '/favicon.ico';
			return $this->_data_url;
    	}

    	/**
    	 *
    	 * Enter description here ...
    	 * @param $favicon_array
    	 * @param $url
    	 */
		function ExecuteFilter(/*array*/ $favicon_array, /*string*/ $url, $data)
		{
			// check that we did not get a redirected page



			$id = Database::LogFaviconFound(array(
				 			'uri' => $url,
							'type' => 'ico',
							'filetypesure' => false,
							'data' => $data,
							'default' => false,
							'comment' => $url,
							'source'=> 'root'));
			$favicon_array['type'] = 'ico';
			$favicon_array['data'] = $data;
			$favicon_array['id'] = $id;
			EdlUtils::favicon_page_msg($url,' [IN_ROOT] FOUND !');

			//
			// @todo 0.5.0 this icon could be a redirected page also
			// should handle redirect also for shorteners better
			//

 			return $favicon_array;
		}

	}
}
