<?php
/**
 * @package WP-Favicons
 */
/*
 Plugin Name: WP-FavIcons
 Plugin URI: http://wordpress.org/extend/plugins/wp-favicons/
 Description: Faviconize your content and your widgets!
 Author: Edward de Leau
 Author URI: http://edward.de.leau.net
 Version: 0.4.0
 License: GPLv2, Copyright 2008,2009,2010,2011  edward de Leau  (email : deleau@gmail.com)
 */
/*
 Installation:
 1. Upload the directory in your plugins directory
 2. Activate the plugin from your WordPress admin 'Plugins' page.
 3. There are no admin pages yet

 Background:
 see: http://wordpress.stackexchange.com/questions/7875/plugin-that-inserts-favicon-next-to-links
 */
/*
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
/**
 * The main plugin file contains the regular WordPress plugin tasks:
 * - actions to perform on activation
 * - actions to perform on deactivation
 * - actions to perform on deinstall
 * - internationalization
 *
 * whereafter:
 * - load of specific plugin configuration data
 * - call the generic plugin framework init method
 *
 * the directory /includes contains all generic plugin independent classes apart from the
 * class-load-configuration.php which is specific and some functions in
 * the util class.
 *
 * the directory /plugins contains all specific functionality divided in
 * modules and per module a set of plugins
 */

/** @ignore */
ini_set('display_errors',1);
error_reporting(E_ALL & ~E_STRICT);

/**
 * To run when this plugin is activated
 * {@link http://codex.wordpress.org/Function_Reference/register_activation_hook}
 */
register_activation_hook( __FILE__ , 'wp_favicons_install');

function wp_favicons_install() {
	global $wp_version;
	if (version_compare($wp_version, "3.1", "<")) {
		deactivate_plugins(basename( __FILE__ ));
		wp_die("This plugin requires WordPress version 3.1 or higher");
	}
	if (version_compare(phpversion(), "5.3.0", "<")) {
		deactivate_plugins(basename( __FILE__ ));
		wp_die("This plugin requires at least PHP version 5.3.0, your version: " . PHP_VERSION . "\n".
			"Please ask your hosting company to bring your PHP version up to date.");
	}
	$wp_favicons = get_option('wp_favicons_options');
	$wp_favicons['FINAL'] = false;
	update_option('wp_favicons_options', $wp_favicons);
}

/**
 * To run when this plugin is deactivated
 * {@link http://codex.wordpress.org/Function_Reference/register_deactivation_hook}
 */
register_deactivation_hook( __FILE__ ,'wp_favicons_uninstall');
function wp_favicons_uninstall() {
	//
}

/**
 * To run when the plugin is deinstalled
 */
if ( function_exists('register_uninstall_hook') )
        register_uninstall_hook(__FILE__, 'wp_favicons_uninstall_hook');
function wp_favicons_uninstall_hook()
{
	delete_option('wp_favicons_options');
	// @todo 0.5.0 delete 2 db
}

/**
 *  I18N / Internationalization
 */
add_action( 'init', 'wpfavicons_load_plugin_textdomain' );
function wpfavicons_load_plugin_textdomain() {
	load_plugin_textdomain( 'wp-favicons', null, basename(dirname( __FILE__  )) .
	 '/includes/languages' );
}

/**
 * load specific configuration and run with extra php check to not fail on
 * older PHP versions
 */
if (version_compare(phpversion(), "5.3.0", ">=")) {
	require_once dirname( __FILE__  ) . '/includes/class-load-configuration.php';
	require_once dirname( __FILE__  ) . '/includes/class-init.php';
}
